==> haskell-wai-http2-extra-0.1.3-365-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-ANpkQyJB1TY1uA2ptwBjsh
key:                  wai-http2-extra-0.1.3-ANpkQyJB1TY1uA2ptwBjsh
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  b467f8a010db4583810338b180424a7d
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-ANpkQyJB1TY1uA2ptwBjsh
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-Ab6499xPt6j7ocIybq2ygA
    psqueues-0.2.8.2-5uYAbSvTTX4LgkiMPVXkjM
    wai-3.2.4-L3dKuQqjqvcGg94VR3jCz4 warp-3.4.0-LfUCTpM1bnI8xt0ZKskiuC
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-http2-extra-0.1.3-366-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-4OXr8y9U4VMFcp2zqBgZhy
key:                  wai-http2-extra-0.1.3-4OXr8y9U4VMFcp2zqBgZhy
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  798d0fbe9b87f3fc88b00a04331d86d8
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-4OXr8y9U4VMFcp2zqBgZhy
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-Ab6499xPt6j7ocIybq2ygA
    psqueues-0.2.8.2-5uYAbSvTTX4LgkiMPVXkjM
    wai-3.2.4-L3dKuQqjqvcGg94VR3jCz4 warp-3.4.0-2lWPYYPo1DQ9GQAHs0s6t9
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
